@@ -29,7 +29,7 @@ class AddEditScenarioWindow(ChildWindow):
         super(AddEditScenarioWindow, self).__init__(*args,
                                                     **kwargs)
 
-    def _setup(self):
+    def _draw_widgets(self):
         self.title(u"Add/Edit Intercept Scenario")
 
         self.config = AddEditScenarioFrame(parent=self._main_frame,
