@@ -217,7 +217,7 @@ class InterceptUpdaters(MutableMapping):
             _ = updater_module.update
 
         except (AttributeError, NameError):
-            logging.error(u'Updater {updater} not loaded as it does not contain a function '
+            logging.debug(u'Updater {updater} not loaded as it does not contain a function '
                           u'called "update"'.format(updater=updater_module_path))
         else:
             self.registered_updaters[updater_key][UpdaterConstant.module] = updater_module
