@@ -21,17 +21,22 @@ Parameters : string containing a pickled requests
 """
 
 import pickle
+import logging_helper
+
+logging = logging_helper.setup_logging()
 
 
 def modify(uri,
-           parameters):
+           modifier):
 
-    if parameters.passes_filter(uri):
+    if modifier.passes_filter(value=uri,
+                              wildcards=u'*'):
         # Raw bytes were pasted for the pickled response.
         # By the time it gets to us, it's a unicode string.
         # This can cause unpickling to fail.
         # We need to convert it back to raw bytes
-        pickled = r''.join([chr(ord(b)) for b in parameters.params])
+        pickled = r''.join([chr(ord(b)) for b in modifier.params])
+        logging.info(u'replacing original with pickled response')
         return pickle.loads(pickled)
 
     return None
